@@ -63,8 +63,9 @@ def patch_kombu_redis():
 # noinspection PyAttributeOutsideInit
 class KombuConsumer(AbstractConsumer, ):
     """
-
+    使用kombu作为中间件,这个能直接一次性支持很多种小众中间件，但性能很差，除非是分布式函数调度框架没实现的中间件种类用户才可以用这种，用户也可以自己对比性能。
     """
+
     BROKER_KIND = 15
 
     def custom_init(self):
@@ -80,7 +81,8 @@ class KombuConsumer(AbstractConsumer, ):
     def _shedual_task(self):  # 这个倍while 1 启动的，会自动重连。
         def callback(body: dict, message: kombu.transport.virtual.base.Message):
             # print(type(body),body,type(message),message)
-            self.logger.debug(f""" 从 kombu {self._middware_name} 中取出的消息是 {body}""")
+            self._print_message_get_from_broker('kombu',body)
+            # self.logger.debug(f""" 从 kombu {self._middware_name} 中取出的消息是 {body}""")
             kw = {'body': body, 'message': message, }
             self._submit_task(kw)
 
@@ -88,16 +90,6 @@ class KombuConsumer(AbstractConsumer, ):
         self.queue = Queue(self._queue_name, exchange=self.exchange, routing_key=self._queue_name, auto_delete=False)
         self.conn = Connection(frame_config.KOMBU_URL, transport_options={"visibility_timeout": 600})  # 默认3600秒unacked重回队列
         self.queue(self.conn).declare()
-
-        # self.producer = self.conn.Consumer(serializer='json')
-        # self.channel = self.producer.channel  # type: Channel
-        #
-        # self.conn = Connection(frame_config.KOMBU_URL)
-        # # self.queue(self.conn).declare()
-        # self.channel = self.conn.channel()  # type: Channel
-        # # self.channel.exchange_declare(exchange='distributed_framework_exchange', durable=True, type='direct')
-        # self.queue = self.channel.queue_declare(queue=self._queue_name, durable=True)
-
         with  self.conn.Consumer(self.queue, callbacks=[callback], no_ack=False, prefetch_count=100)  as consumer:
             # Process messages and handle events on all channels
             channel = consumer.channel  # type:Channel
