@@ -12,7 +12,7 @@ from wtforms.validators import DataRequired, Length
 from flask_login import login_user, logout_user, login_required, LoginManager, UserMixin
 
 from function_scheduling_distributed_framework import nb_print
-from distributed_frame_config.function_result_web.functions import get_cols, query_result, get_speed, Statistic
+from function_scheduling_distributed_framework.function_result_web.functions import get_cols, query_result, get_speed, Statistic
 
 app = Flask(__name__)
 app.secret_key = 'mtfy54321'
